@@ -166,13 +166,7 @@ void KStars::slotWizard() {
 
         // If the sky is in Horizontal mode and not tracking, reset focus such that
         // Alt/Az remain constant.
-        if ( data()->useDefaultOptions ) {
-            SkyPoint newPoint;
-            newPoint.setAz( Options::focusRA() );
-            newPoint.setAlt( Options::focusDec() + 0.0001 );
-            newPoint.HorizontalToEquatorial( LST(), geo()->lat() );
-            map()->setDestination( &newPoint );
-        } else if ( ! Options::isTracking() && Options::useAltAz() ) {
+        if ( ! Options::isTracking() && Options::useAltAz() ) {
             map()->focus()->HorizontalToEquatorial( LST(), geo()->lat() );
         }
 
@@ -393,7 +387,7 @@ void KStars::slotViewOps() {
     dialog->addPage(opguides, i18n("Guides"), "kstars_guides");
     dialog->addPage(opcolors, i18n("Colors"), "kstars_colors");
     dialog->addPage(opadvanced, i18n("Advanced"), "kstars_advanced");
-
+    dialog->setHelp(QString(), "kstars");
     dialog->show();
 }
 
@@ -977,9 +971,9 @@ void KStars::slotTipOfDay() {
 void KStars::slotFullScreen()
 {
     if ( topLevelWidget()->isFullScreen() ) {
-        topLevelWidget()->showNormal();
+        topLevelWidget()->setWindowState( topLevelWidget()->windowState() & ~Qt::WindowFullScreen ); // reset
     } else {
-        topLevelWidget()->showFullScreen();
+        topLevelWidget()->setWindowState( topLevelWidget()->windowState() | Qt::WindowFullScreen ); // set
     }
 }
 
@@ -1074,7 +1068,7 @@ void KStars::slotAboutToQuit()
     Options::setWindowHeight( height() );
 
     //explicitly save the colorscheme data to the config file
-    data()->colorScheme()->saveToConfig( KGlobal::config().data() );
+    data()->colorScheme()->saveToConfig();
 
     KConfigGroup cg = KGlobal::config()->group( "MainToolBar" );
     //explicitly save toolbar settings to config file
