@@ -635,10 +635,10 @@ void KStars::datainitFinished(bool worked) {
 
 void KStars::initFocus() {
     SkyPoint newPoint;
-    //If useDefaultOptions, then we set Az/Alt.  Otherwise, set RA/Dec
-    if ( data()->useDefaultOptions ) {
+
+    if ( Options::focusRA() == 180.0 && Options::focusDec() == 45.0 ) {
         newPoint.setAz( Options::focusRA() );
-        newPoint.setAlt( Options::focusDec() + 0.0001 );
+        newPoint.setAlt( Options::focusDec() );
         newPoint.HorizontalToEquatorial( LST(), geo()->lat() );
     } else {
         newPoint.set( Options::focusRA(), Options::focusDec() );
@@ -665,9 +665,7 @@ void KStars::initFocus() {
 
     data()->setSnapNextFocus();
     map()->setDestination( map()->focusPoint() );
-    map()->destination()->EquatorialToHorizontal( LST(), geo()->lat() );
     map()->setFocus( map()->destination() );
-    map()->focus()->EquatorialToHorizontal( LST(), geo()->lat() );
 
     map()->showFocusCoords();
 
@@ -702,11 +700,8 @@ void KStars::initFocus() {
         ((KSPlanetBase*)map()->focusObject())->addToTrail();
         data()->temporaryTrail = true;
     }
-
-    //Store focus coords in Options object before calling applyConfig()
-    Options::setFocusRA( map()->focus()->ra()->Hours() );
-    Options::setFocusDec( map()->focus()->dec()->Degrees() );
 }
+
 void KStars::buildGUI() {
     //create the skymap
     skymap = SkyMap::Create( data(), this );
