@@ -49,6 +49,7 @@
 #include <KPageWidget>
 #include <kdeprintdialog.h>
 #include <KProcess>
+#include <kwindowsystem.h>
 
 #include "keduvocdocument.h"
 #include "kwqtablemodel.h"
@@ -540,7 +541,7 @@ void KWordQuizApp::openUrl(const KUrl& url)
           if(a->m_doc->url().path() == url.path())
           {
             if (w->isMinimized())
-              w->showNormal();
+              KWindowSystem::unminimizeWindow(w->winId());
             w->activateWindow();
             w->raise();
             break;
@@ -767,7 +768,8 @@ void KWordQuizApp::slotFileSave()
   }
   else
   {
-    if (!m_doc->saveAs(m_doc->url(), KEduVocDocument::Automatic, QString("kwordquiz %1").arg(KWQ_VERSION))) {
+    int saveStatus = m_doc->saveAs(m_doc->url(), KEduVocDocument::Automatic, QString("kwordquiz %1").arg(KWQ_VERSION));
+    if (saveStatus != KEduVocDocument::NoError) {
       slotFileSaveAs();
     }
   }
@@ -824,7 +826,7 @@ bool KWordQuizApp::saveAsFileName( )
 
       QFileInfo fileinfo(url.path());
       if (fileinfo.exists() && KMessageBox::warningContinueCancel(0,
-          i18n("The file<br /><b>%1</b><br />already exists. Do you want to overwrite it?",
+          i18n("<html>The file<br /><b>%1</b><br />already exists. Do you want to overwrite it?</html>",
                url.path()),QString(),KStandardGuiItem::overwrite()) == KMessageBox::Cancel)
       {
       // do nothing
