@@ -46,7 +46,6 @@ class MarbleControlBoxPrivate
     MarbleWidget  *m_widget;
     QString        m_searchTerm;
     bool           m_searchTriggered;
-    int            m_minimumzoom;
 
     Ui::MarbleControlBox  uiWidget;
     QWidget              *m_navigationWidget;
@@ -70,8 +69,6 @@ MarbleControlBox::MarbleControlBox(QWidget *parent)
     d->m_widget = 0;
     d->m_searchTerm = QString();
     d->m_searchTriggered = false;
-    // FIXME: Get this from MapTheme.
-    d->m_minimumzoom = 900;
 
     d->uiWidget.setupUi( this );
 
@@ -226,6 +223,8 @@ void MarbleControlBox::addMarbleWidget(MarbleWidget *widget)
 #endif
 
     // Initialize the MarbleLegendBrowser
+    d->uiWidget.marbleLegendBrowser->setMarbleWidget( d->m_widget );
+
     d->uiWidget.marbleLegendBrowser->setCheckedLocations( d->m_widget->showPlaces() );
     d->uiWidget.marbleLegendBrowser->setCheckedCities( d->m_widget->showCities() );
     d->uiWidget.marbleLegendBrowser->setCheckedTerrain( d->m_widget->showTerrain() );
@@ -252,9 +251,12 @@ void MarbleControlBox::addMarbleWidget(MarbleWidget *widget)
 
     connect( this, SIGNAL( projectionSelected( int ) ),  d->m_widget, SLOT( setProjection( int ) ) );
 
-    connect( d->m_widget, SIGNAL(themeChanged( QString )), this, SLOT( selectTheme( QString )) );
+    connect( d->m_widget, SIGNAL( themeChanged( QString ) ),
+             this,        SLOT( selectTheme( QString ) ) );
     selectTheme( d->m_widget->mapTheme() );
-    connect( d->m_widget, SIGNAL(projectionChanged( int )), this, SLOT( selectProjection( int )) );
+
+    connect( d->m_widget, SIGNAL( projectionChanged( int ) ),
+             this,        SLOT( selectProjection( int ) ) );
     selectProjection( d->m_widget->projection() );
 
     connect(d->m_widget, SIGNAL(zoomChanged(int)),
@@ -338,7 +340,7 @@ void MarbleControlBox::setLocations(QAbstractItemModel* locations)
 
 int MarbleControlBox::minimumZoom() const
 {
-    return d->m_minimumzoom;
+    return d->m_widget->minimumZoom();
 }
 
 
@@ -347,7 +349,7 @@ void MarbleControlBox::changeZoom(int zoom)
     // No infinite loops here
     // if (zoomSlider->value() != zoom)
     d->uiWidget.zoomSlider->setValue( zoom );
-    d->uiWidget.zoomSlider->setMinimum( d->m_minimumzoom );
+    d->uiWidget.zoomSlider->setMinimum( minimumZoom() );
 }
 
 void MarbleControlBox::disableGpsInput( bool in )
@@ -464,17 +466,21 @@ void MarbleControlBox::setFileViewTabShown( bool show )
 
 void MarbleControlBox::resizeEvent ( QResizeEvent * )
 {
-    if ( height() < 480 ) {
+    if ( height() < 500 ) {
         if ( !d->uiWidget.zoomSlider->isHidden() ) {
+            setUpdatesEnabled(false);
             d->uiWidget.zoomSlider->hide();
             d->uiWidget.m_pSpacerFrame->setSizePolicy( QSizePolicy::Preferred,
                                                        QSizePolicy::Expanding );
+            setUpdatesEnabled(true);
         }
     } else {
         if ( d->uiWidget.zoomSlider->isHidden() == true ) {
+            setUpdatesEnabled(false);
             d->uiWidget.zoomSlider->show();
             d->uiWidget.m_pSpacerFrame->setSizePolicy( QSizePolicy::Preferred,
                                                        QSizePolicy::Fixed );
+            setUpdatesEnabled(true);
         }
     }
 }
@@ -502,14 +508,30 @@ void MarbleControlBox::selectTheme( const QString &theme )
 {
     for ( int row = 0; row < d->m_mapthememodel->rowCount(); ++row ) {
         QModelIndex itIndexName = d->m_mapthememodel->index( row, 1, QModelIndex() );
-        QModelIndex itIndex = d->m_mapthememodel->index( row, 0, QModelIndex() );
-//        qDebug() << "Select Theme: " << theme << " Stored: " << d->m_mapthememodel->data( itIndexName ).toString();
-        if ( theme == d->m_mapthememodel->data( itIndexName ).toString() ) {
-              if ( itIndexName != d->uiWidget.marbleThemeSelectView->currentIndex() ) {
-                d->uiWidget.marbleThemeSelectView->setCurrentIndex( itIndex );
-                d->uiWidget.marbleThemeSelectView->scrollTo( itIndex );
-                break;
-              }
+        QModelIndex itIndex     = d->m_mapthememodel->index( row, 0, QModelIndex() );
+        // qDebug() << "Select Theme: " << theme << " Stored: " << d->m_mapthememodel->data( itIndexName ).toString();
+
+        // If  we have found the theme in the theme model,
+        //     and it is not the one that we already have,
+        // then
+        //     set the new one in the ui.
+        if ( theme == d->m_mapthememodel->data( itIndexName ).toString()
+             && itIndexName != d->uiWidget.marbleThemeSelectView->currentIndex() ) {
+            // Mark the correct picture for the selected map theme and
+            // also make sure it's shown.
+            d->uiWidget.marbleThemeSelectView->setCurrentIndex( itIndex );
+            d->uiWidget.marbleThemeSelectView->scrollTo( itIndex );
+
+            // Dig out the min and max zoom and set the slider.
+            //
+            // Since this slot is called when a change of map theme is
+            // already finished, we can use the widget to get the
+            // values.
+            d->uiWidget.zoomSlider->setMinimum( d->m_widget->model()->minimumZoom() );
+            d->uiWidget.zoomSlider->setMaximum( d->m_widget->model()->maximumZoom() );
+
+            // Break out of the loop
+            break;
         }
     }
 }
