@@ -56,26 +56,23 @@
 class MarbleWidgetPrivate
 {
  public:
-
     // The model we are showing.
     MarbleModel     *m_model;
 
     ViewParams       m_viewParams;
     bool             m_justModified; // FIXME: Rename to isDirty
 
-    GeoDataPoint         m_homePoint;
+    GeoDataPoint     m_homePoint;
     int              m_homeZoom;
 
     int              m_logzoom;
 
     int              m_zoomStep;
-    int              m_minimumzoom;
-    int              m_maximumzoom;
 
     MarbleWidgetInputHandler  *m_inputhandler;
     MarbleWidgetPopupMenu     *m_popupmenu;
 
-    TextureColorizer        *m_sealegend;
+    TextureColorizer          *m_sealegend;
 
     // Parameters for the widgets appearance.
     bool             m_showCompass;
@@ -84,9 +81,9 @@ class MarbleWidgetPrivate
     bool             m_showFrameRate;
 
     // Parts of the image in the Widget
-    CrossHairFloatItem  m_crosshair;
-    CompassFloatItem    m_compass;  // Shown in the upper right
-    MapScaleFloatItem   m_mapscale; // Shown in the lower left
+    CrossHairFloatItem         m_crosshair;
+    CompassFloatItem           m_compass;  // Shown in the upper right
+    MapScaleFloatItem          m_mapscale; // Shown in the lower left
 
     // Tools
     MeasureTool     *m_measureTool;
@@ -144,11 +141,13 @@ void MarbleWidget::construct(QWidget *parent)
 
     connect( d->m_model, SIGNAL( regionChanged( BoundingBox ) ) ,
              this, SLOT(updateRegion( BoundingBox) ) );
+
+
     // Set background: black.
-    QPalette p = palette();
-    p.setColor( QPalette::Window, Qt::black );
-    setPalette( p );
-    setBackgroundRole( QPalette::Window );
+    setPalette( QPalette ( Qt::black ) );
+
+    // Set whether the black space gets displayed or the earth gets simply 
+    // displayed on the widget background.
     setAutoFillBackground( true );
 
     d->m_justModified = false;
@@ -168,12 +167,11 @@ void MarbleWidget::construct(QWidget *parent)
     connect( d->m_model, SIGNAL( timeout() ),
              this,       SLOT( updateGps() ) );
 
+
     d->m_logzoom  = 0;
     d->m_zoomStep = 40;
-    goHome();
 
-    d->m_minimumzoom = 950;
-    d->m_maximumzoom = 2400;
+    goHome();
 
     d->m_showScaleBar  = true;
     d->m_showCompass   = true;
@@ -298,9 +296,14 @@ double MarbleWidget::centerLongitude() const
     return centerLon * RAD2DEG;
 }
 
-void MarbleWidget::setMinimumZoom( int zoom )
+int  MarbleWidget::minimumZoom() const
 {
-    d->m_minimumzoom = zoom;
+    return d->m_model->minimumZoom();
+}
+
+int  MarbleWidget::maximumZoom() const
+{
+    return d->m_model->maximumZoom();
 }
 
 void MarbleWidget::addPlaceMarkFile( const QString &filename )
@@ -393,42 +396,48 @@ bool  MarbleWidget::quickDirty() const
     return d->m_model->textureMapper()->interlaced();
 }
 
-void MarbleWidget::zoomView(int zoom)
+void MarbleWidget::zoomView(int newZoom)
 {
+    // Check for under and overflow.
+    if ( newZoom < minimumZoom() ) {
+        newZoom = minimumZoom();
+    }
+    else if ( newZoom > maximumZoom() ) {
+        newZoom = maximumZoom();
+    }
+
     // Prevent infinite loops.
-    if ( zoom  == d->m_logzoom )
+    if ( newZoom  == d->m_logzoom )
 	return;
 
-    d->m_logzoom = zoom;
+    d->m_logzoom = newZoom;
 
+    emit zoomChanged( newZoom );
 
-    emit zoomChanged(zoom);
-
-    int newRadius = fromLogScale(zoom);
+    int newRadius = fromLogScale( newZoom );
 
     if ( newRadius == radius() )
 	return;
 
     // Clear canvas if the globe is visible as a whole or if the globe
     // does shrink.
-    int  imageHalfWidth = d->m_viewParams.m_canvasImage->width() / 2;
-    int  imageHalfHeight = d->m_viewParams.m_canvasImage->height() / 2;
-
-    if ( newRadius * newRadius < imageHalfWidth * imageHalfWidth + imageHalfHeight * imageHalfHeight
-         && newRadius != radius() 
-         || d->m_viewParams.m_projection == Equirectangular )
+    if ( ! globeCoversImage()
+         || d->m_viewParams.m_projection != Equirectangular )
     {
-        setAttribute(Qt::WA_NoSystemBackground, false);
-        d->m_viewParams.m_canvasImage->fill( Qt::transparent );
+        setAttribute( Qt::WA_NoSystemBackground, false );
+        d->m_viewParams.m_canvasImage->fill( Qt::black );
     }
     else {
-        setAttribute(Qt::WA_NoSystemBackground, true);
+        setAttribute( Qt::WA_NoSystemBackground, true );
     }
 
     setRadius( newRadius );
 
     emit distanceChanged( distanceString() );
 
+    // We don't do this on every paintEvent to improve performance.
+    // Redrawing the atmosphere is only needed if the size of the 
+    // globe changes.
     drawAtmosphere();
 
     repaint();
@@ -439,21 +448,7 @@ void MarbleWidget::zoomView(int zoom)
 
 void MarbleWidget::zoomViewBy( int zoomStep )
 {
-    // Prevent infinite loops
-
-    int zoom    = radius();
-    int tryZoom = toLogScale( zoom ) + zoomStep;
-    // qDebug() << QString::number(tryZoom) << " "
-    //         << QString::number(minimumzoom);
-    if ( tryZoom < d->m_minimumzoom ) {
-        tryZoom = d->m_minimumzoom;
-    }
-    else if ( tryZoom > d->m_maximumzoom ) {
-        tryZoom = d->m_maximumzoom;
-    }
-
-    zoom = tryZoom;
-    zoomView( zoom );
+    zoomView( toLogScale( radius() ) + zoomStep );
 }
 
 
@@ -470,6 +465,9 @@ void MarbleWidget::zoomOut()
 void MarbleWidget::rotateTo(const Quaternion& quat)
 {
     d->m_viewParams.m_planetAxis = quat;
+
+    // This method doesn't force a repaint of the view on purpose!
+    // See header file.
 }
 
 
@@ -496,7 +494,7 @@ void MarbleWidget::rotateBy( const double& deltaLon, const double& deltaLat)
 void MarbleWidget::centerOn(const double& lon, const double& lat)
 {
     d->m_viewParams.m_planetAxis.createFromEuler( -lat * DEG2RAD,
-                                                  lon * DEG2RAD,
+                                                   lon * DEG2RAD,
                                                   0.0 );
 //    d->m_viewParams.m_planetAxis.display();
     repaint();
@@ -566,26 +564,25 @@ void MarbleWidget::setProjection( int projectionIndex )
     d->m_viewParams.m_oldProjection = d->m_viewParams.m_projection;
     d->m_viewParams.m_projection = projection;
 
-    int  imageHalfWidth = d->m_viewParams.m_canvasImage->width() / 2;
-    int  imageHalfHeight = d->m_viewParams.m_canvasImage->height() / 2;
-
-    if ( radius() * radius() < imageHalfWidth * imageHalfWidth + imageHalfHeight * imageHalfHeight
-         || d->m_viewParams.m_projection == Equirectangular )
+    if ( !globeCoversImage() 
+         || d->m_viewParams.m_projection != Spherical )
     {
         setAttribute(Qt::WA_NoSystemBackground, false);
-        d->m_viewParams.m_canvasImage->fill( Qt::transparent );
+        d->m_viewParams.m_canvasImage->fill( Qt::black );
     }
     else {
         setAttribute(Qt::WA_NoSystemBackground, true);
     }
 
+    drawAtmosphere();
+
     // Update texture map during the repaint that follows:
     setMapTheme( d->m_model->mapTheme() );
     setNeedsUpdate();
     repaint();
 }
 
-void MarbleWidget::home( double &lon, double &lat, int& zoom)
+void MarbleWidget::home( double &lon, double &lat, int& zoom )
 {
     d->m_homePoint.geoCoordinates( lon, lat, GeoDataPoint::Degree );
     zoom = d->m_homeZoom;
@@ -633,12 +630,12 @@ void MarbleWidget::moveRight()
 
 void MarbleWidget::moveUp()
 {
-    rotateBy( 0, moveStep() );
+    rotateBy( 0, -moveStep() );
 }
 
 void MarbleWidget::moveDown()
 {
-    rotateBy( 0, -moveStep() );
+    rotateBy( 0, +moveStep() );
 }
 
 void MarbleWidget::leaveEvent (QEvent*)
@@ -660,9 +657,9 @@ void MarbleWidget::resizeEvent (QResizeEvent*)
     int  imageWidth2  = width() / 2;
     int  imageHeight2 = height() / 2;
 
-    if ( radius() < imageWidth2 * imageWidth2 + imageHeight2 * imageHeight2 ) {
+    if ( ! globeCoversImage() ) {
         setAttribute(Qt::WA_NoSystemBackground, false);
-        d->m_viewParams.m_canvasImage->fill( Qt::transparent );
+        d->m_viewParams.m_canvasImage->fill( Qt::black );
     }
     else {
         setAttribute(Qt::WA_NoSystemBackground, true);
@@ -848,27 +845,38 @@ void MarbleWidget::rotateTo(const double& lon, const double& lat)
 
 void MarbleWidget::drawAtmosphere()
 {
-    if( d->m_viewParams.m_projection == Spherical ) {
-        int  imageHalfWidth  = width() / 2;
-        int  imageHalfHeight = height() / 2;
+    // Only draw an atmosphere if projection is spherical
+    if ( d->m_viewParams.m_projection != Spherical )
+        return;
 
-        // Recalculate the atmosphere effect and paint it to canvasImage.
-        QRadialGradient grad1( QPointF( imageHalfWidth, imageHalfHeight ),
-                            1.05 * radius() );
-        grad1.setColorAt( 0.91, QColor( 255, 255, 255, 255 ) );
-        grad1.setColorAt( 1.00, QColor( 255, 255, 255, 0 ) );
+    // No use to draw atmosphere if it's not visible in the area.
+    if ( globeCoversImage() )
+        return;
 
-        QBrush    brush1( grad1 );
-        QPen      pen1( Qt::NoPen );
-        QPainter  painter( d->m_viewParams.m_canvasImage );
-        painter.setBrush( brush1 );
-        painter.setPen( pen1 );
-        painter.setRenderHint( QPainter::Antialiasing, false );
-        painter.drawEllipse( imageHalfWidth - (int)( (double)(radius()) * 1.05 ),
-                            imageHalfHeight - (int)( (double)(radius()) * 1.05 ),
-                            (int)( 2.1 * (double)(radius()) ),
-                            (int)( 2.1 * (double)(radius()) ) );
-    }
+    // Ok, now we know that at least a little of the atmosphere is
+    // visible, if nothing else in the corners.  Draw the atmosphere
+    // by using a circular gradient.  This is a pure visual effect and
+    // has nothing to do with real physics.
+
+    int  imageHalfWidth  = width() / 2;
+    int  imageHalfHeight = height() / 2;
+
+    // Recalculate the atmosphere effect and paint it to canvasImage.
+    QRadialGradient grad1( QPointF( imageHalfWidth, imageHalfHeight ),
+                        1.05 * radius() );
+    grad1.setColorAt( 0.91, QColor( 255, 255, 255, 255 ) );
+    grad1.setColorAt( 1.00, QColor( 255, 255, 255, 0 ) );
+
+    QBrush    brush1( grad1 );
+    QPen      pen1( Qt::NoPen );
+    QPainter  painter( d->m_viewParams.m_canvasImage );
+    painter.setBrush( brush1 );
+    painter.setPen( pen1 );
+    painter.setRenderHint( QPainter::Antialiasing, false );
+    painter.drawEllipse( imageHalfWidth - (int)( (double)(radius()) * 1.05 ),
+                        imageHalfHeight - (int)( (double)(radius()) * 1.05 ),
+                        (int)( 2.1 * (double)(radius()) ),
+                        (int)( 2.1 * (double)(radius()) ) );
 }
 
 
@@ -882,8 +890,10 @@ void MarbleWidget::setActiveRegion()
     switch( d->m_viewParams.m_projection ) {
         case Spherical:
             if ( zoom < sqrt( width() * width() + height() * height() ) / 2 ) {
-	       d->m_activeRegion &= QRegion( width() / 2 - zoom, height() / 2 - zoom,
-                                       2 * zoom, 2 * zoom, QRegion::Ellipse );
+	       d->m_activeRegion &= QRegion( width()  / 2 - zoom, 
+                                             height() / 2 - zoom,
+                                             2 * zoom, 2 * zoom, 
+                                             QRegion::Ellipse );
             }
             break;
         case Equirectangular:
@@ -893,7 +903,9 @@ void MarbleWidget::setActiveRegion()
 
             int yCenterOffset =  (int)((double)(2*zoom) / M_PI * centerLat);
             int yTop = height()/2 - zoom + yCenterOffset;
-            d->m_activeRegion &= QRegion( 0, yTop, width(), 2 * zoom, QRegion::Rectangle );
+            d->m_activeRegion &= QRegion( 0, yTop, 
+                                          width(), 2 * zoom,
+                                          QRegion::Rectangle );
             break;
     }
 }
@@ -965,7 +977,7 @@ void MarbleWidget::paintEvent(QPaintEvent *evt)
         painter.drawPixmap( d->m_viewParams.m_canvasImage->width() - 60, 10,
                             d->m_compass.drawCompassPixmap( d->m_viewParams.m_canvasImage->width(),
                                                             d->m_viewParams.m_canvasImage->height(),
-                                                            northPoleY() ) );
+                                                            northPoleY(), d->m_viewParams.m_projection ) );
 
     // 3. Paint the scale.
     if ( d->m_showScaleBar )
@@ -1044,7 +1056,8 @@ QString MarbleWidget::mapTheme() const
 
 void MarbleWidget::setMapTheme( const QString& maptheme )
 {
-    if ( maptheme == d->m_model->mapTheme() && d->m_viewParams.m_projection == d->m_viewParams.m_oldProjection)
+    if ( maptheme == d->m_model->mapTheme()
+         && d->m_viewParams.m_projection == d->m_viewParams.m_oldProjection )
         return;
 
     d->m_model->setMapTheme( maptheme, this, d->m_viewParams.m_projection );
@@ -1308,4 +1321,21 @@ QString MarbleWidget::distanceString() const
     return QString( "%L1 %2" ).arg( distance, 8, 'f', 1, QChar(' ') ).arg( tr("km") );
 }
 
+
+bool MarbleWidget::globeCoversImage() const
+{
+    // This first test is a quick one that will catch all really big
+    // radii and prevent overflow in the real test.
+    if ( radius() > width() + height() )
+        return true;
+
+    // This is the real test.  The 4 is because we are really
+    // comparing to width/2 and height/2.
+    if ( 4 * radius() * radius() >= width() * width() + height() * height() )
+        return true;
+
+    return false;
+}
+
+
 #include "MarbleWidget.moc"
