@@ -58,7 +58,7 @@ class FileViewModel;
  * the mouse.
  *
  * By clicking on the globe and moving the mouse, the position can be
- * moved.  The user can also zoom by using the scroll wheel of the
+ * changed.  The user can also zoom by using the scroll wheel of the
  * mouse in the widget. The zoom value is not tied to any units, but
  * is an abstract value without any physical meaning. A value around
  * 1000 shows the full globe in a normal-sized window. Higher zoom
@@ -125,6 +125,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     Q_PROPERTY(bool quickDirty   READ quickDirty      WRITE setQuickDirty)
 
  public:
+
     /**
      * @brief Construct a new MarbleWidget.
      * @param parent the parent widget
@@ -167,6 +168,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     void setDownloadManager(HttpDownloadManager *downloadManager);
 
+
     /**
      * @brief Return the active region in which it's possible to drag the view using the mouse.
      */
@@ -194,10 +196,14 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     QString     distanceString() const;
 
     /**
-     * @brief  Set the minimum value for the zoom.
-     * @param  zoom  The new minimum value.
+     * @brief return the minimum zoom value for the current map theme.
      */
-    void        setMinimumZoom( int zoom );
+    int         minimumZoom() const;
+
+    /**
+     * @brief return the minimum zoom value for the current map theme.
+     */
+    int         maximumZoom() const;
 
     /**
      * @brief return if the widget needs to be updated.
@@ -401,6 +407,9 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     bool  quickDirty() const;
 
+    bool globeCoversImage() const;
+
+
  public Q_SLOTS:
 
     /**
@@ -536,6 +545,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      * @return @c Mercator          another flat map
      */
     Projection  projection() const;
+
     /**
      * @brief  Set the Projection used for the map
      * @param  projection projection type (e.g. Spherical, Equirectangular, Mercator)
